==> restfulSE_1.0.1.tar.gz: restfulSE/inst/doc/restfulSE.R <==
## ----setup,echo=FALSE,results="hide"---------------------------------------
suppressPackageStartupMessages({
library(restfulSE)
library(GO.db)
library(org.Hs.eg.db)
library(SummarizedExperiment)
library(ExperimentHub)
library(AnnotationHub)
})

## ----do10x,eval=FALSE------------------------------------------------------
#  library(restfulSE)
#  my10x = se1.3M()
#  my10x

## ----doanno, eval=FALSE----------------------------------------------------
#  library(org.Mm.eg.db)
#  hippdev = select(org.Mm.eg.db,
#      keys="GO:0021766", keytype="GO", column="ENSEMBL")$ENSEMBL
#  hippdev = intersect(hippdev, rownames(my10x))
#  unname(assay(my10x[ hippdev[1:10], 10001:10006]))

## ----lktiss, eval=TRUE-----------------------------------------------------
tiss = gtexTiss()
tiss

## ----findbr----------------------------------------------------------------
binds = grep("Brain", tiss$smtsd)
table(tiss$smtsd[binds][1:100]) # check diversity in 100 samples

## ----findn-----------------------------------------------------------------
ntgenes = goPatt(termPattern="neurotroph")
head(ntgenes)

## ----setup2,echo=FALSE-----------------------------------------------------
suppressPackageStartupMessages({
library(restfulSE)
library(SummarizedExperiment)
library(Rtsne)
library(rhdf5client)
})

## ----dobanoyy--------------------------------------------------------------
library(restfulSE)
bigec2 = H5S_source("http://54.174.163.77:5000")
bigec2
dsmeta(bigec2)[1:2,] # two groups
dsmeta(bigec2)[1,2][[1]] # all dataset candidates in group 1

## ----doba2-----------------------------------------------------------------
banref = bigec2[["assays"]] # arbitrary name assigned long ago
banref

## ----doba3-----------------------------------------------------------------
ehub = ExperimentHub::ExperimentHub()
myfiles <- AnnotationHub::query(ehub , "restfulSEData")
myfiles[["EH551"]] -> banoSEMeta
#data("banoSEMeta", package = "restfulSEData")
rbano = RESTfulSummarizedExperiment(banoSEMeta, banref)
rbano

## ----doba4-----------------------------------------------------------------
rbanoSub = rbano[5:8, c(3:9, 40:50)] 
assay(rbanoSub) 

## ----gettx-----------------------------------------------------------------
txdat = bigec2[["tenx_100k_sorted"]]
ehub = ExperimentHub::ExperimentHub()
myfiles <- AnnotationHub::query(ehub , "restfulSEData")
myfiles[["EH552"]] -> st100k
#data("st100k", package = "restfulSEData")
tenx100k = RESTfulSummarizedExperiment( st100k, 
   txdat )
tenx100k

## ----anno------------------------------------------------------------------
library(org.Mm.eg.db)
atab = select(org.Mm.eg.db, keys="GO:0021766", keytype="GO", columns="ENSEMBL")
hg = atab[,"ENSEMBL"]
length(hgok <- intersect(hg, rownames(tenx100k)))

## ----getdat, cache=TRUE----------------------------------------------------
hipn = assay(tenx100k[hgok,1:4000])  # slow
d = dist(t(log(1+hipn)), method="manhattan")
proj = Rtsne(d)

## ----plt,fig=TRUE----------------------------------------------------------
plot(proj$Y)

## ----lktas-----------------------------------------------------------------
#data("tasicST6", package = "restfulSEData")
ehub = ExperimentHub::ExperimentHub()
myfiles <- AnnotationHub::query(ehub , "restfulSEData")
myfiles[["EH557"]] -> tasicST6
tasicST6

## ----lkd-------------------------------------------------------------------
library(restfulSE)
#data("banoSEMeta", package = "restfulSEData")
ehub = ExperimentHub::ExperimentHub()
myfiles <- AnnotationHub::query(ehub , "restfulSEData")
myfiles[["EH551"]] -> banoSEMeta
banoSEMeta

## ----doso------------------------------------------------------------------
mys = H5S_source(serverURL="http://54.174.163.77:5000")
mys

## ----lkg-------------------------------------------------------------------
groups(mys)

## ----lkhl------------------------------------------------------------------
lin1 = rhdf5client::links(mys,1)
lin1

==> restfulSE_1.0.2.tar.gz: restfulSE/inst/doc/restfulSE.R <==
## ----setup,echo=FALSE,results="hide"---------------------------------------
suppressPackageStartupMessages({
library(restfulSE)
library(GO.db)
library(org.Hs.eg.db)
library(SummarizedExperiment)
library(ExperimentHub)
library(AnnotationHub)
})

## ----do10x,eval=FALSE------------------------------------------------------
#  library(restfulSE)
#  my10x = se1.3M()
#  my10x

## ----doanno, eval=FALSE----------------------------------------------------
#  library(org.Mm.eg.db)
#  hippdev = select(org.Mm.eg.db,
#      keys="GO:0021766", keytype="GO", column="ENSEMBL")$ENSEMBL
#  hippdev = intersect(hippdev, rownames(my10x))
#  unname(assay(my10x[ hippdev[1:10], 10001:10006]))

## ----lktiss, eval=TRUE-----------------------------------------------------
tiss = gtexTiss()
tiss

## ----findbr----------------------------------------------------------------
binds = grep("Brain", tiss$smtsd)
table(tiss$smtsd[binds][1:100]) # check diversity in 100 samples

## ----findn-----------------------------------------------------------------
ntgenes = goPatt(termPattern="neurotroph")
head(ntgenes)

## ----setup2,echo=FALSE-----------------------------------------------------
suppressPackageStartupMessages({
library(restfulSE)
library(SummarizedExperiment)
library(Rtsne)
library(rhdf5client)
})

## ----dobanoyy--------------------------------------------------------------
library(restfulSE)
bigec2 = H5S_source("http://h5s.channingremotedata.org:5000")
bigec2
dsmeta(bigec2)[1:2,] # two groups
dsmeta(bigec2)[1,2][[1]] # all dataset candidates in group 1

## ----doba2-----------------------------------------------------------------
banref = bigec2[["assays"]] # arbitrary name assigned long ago
banref

## ----doba3-----------------------------------------------------------------
ehub = ExperimentHub::ExperimentHub()
myfiles <- AnnotationHub::query(ehub , "restfulSEData")
myfiles[["EH551"]] -> banoSEMeta
#data("banoSEMeta", package = "restfulSEData")
rbano = RESTfulSummarizedExperiment(banoSEMeta, banref)
rbano

## ----doba4-----------------------------------------------------------------
rbanoSub = rbano[5:8, c(3:9, 40:50)] 
assay(rbanoSub) 

## ----gettx-----------------------------------------------------------------
txdat = bigec2[["tenx_100k_sorted"]]
ehub = ExperimentHub::ExperimentHub()
myfiles <- AnnotationHub::query(ehub , "restfulSEData")
myfiles[["EH552"]] -> st100k
#data("st100k", package = "restfulSEData")
tenx100k = RESTfulSummarizedExperiment( st100k, 
   txdat )
tenx100k

## ----anno------------------------------------------------------------------
library(org.Mm.eg.db)
atab = select(org.Mm.eg.db, keys="GO:0021766", keytype="GO", columns="ENSEMBL")
hg = atab[,"ENSEMBL"]
length(hgok <- intersect(hg, rownames(tenx100k)))

## ----getdat, cache=TRUE----------------------------------------------------
hipn = assay(tenx100k[hgok,1:4000])  # slow
d = dist(t(log(1+hipn)), method="manhattan")
proj = Rtsne(d)

## ----plt,fig=TRUE----------------------------------------------------------
plot(proj$Y)

## ----lktas-----------------------------------------------------------------
#data("tasicST6", package = "restfulSEData")
ehub = ExperimentHub::ExperimentHub()
myfiles <- AnnotationHub::query(ehub , "restfulSEData")
myfiles[["EH557"]] -> tasicST6
tasicST6

## ----lkd-------------------------------------------------------------------
library(restfulSE)
#data("banoSEMeta", package = "restfulSEData")
ehub = ExperimentHub::ExperimentHub()
myfiles <- AnnotationHub::query(ehub , "restfulSEData")
myfiles[["EH551"]] -> banoSEMeta
banoSEMeta

## ----doso------------------------------------------------------------------
mys = H5S_source(serverURL="http://h5s.channingremotedata.org:5000")
mys

## ----lkg-------------------------------------------------------------------
groups(mys)

## ----lkhl------------------------------------------------------------------
lin1 = rhdf5client::links(mys,1)
lin1
